sqlobject.tests.test_indexes module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_indexes module

class `sqlobject.tests.test_indexes.` `AddressIndexGet2`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = address_index_get2
  property `person`
  property `personID`
  `pk` = <sqlobject.index.SODatabaseIndex object>
  `q` = address_index_get2
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = [<sqlobject.index.SODatabaseIndex object>]
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_indexes.AddressIndexGet2`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'address_index_get2'
  property `street`
  property `type`

class `sqlobject.tests.test_indexes.` `PersonIndexGet`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `age`
  classmethod `byAge`(val, connection=None)
  property `firstName`
  `j` = person_index_get
  property `lastName`
  `nameIndex` = <sqlobject.index.SODatabaseIndex object>
  `q` = person_index_get
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = [<sqlobject.index.SODatabaseIndex object>]
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_indexes.PersonIndexGet`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'person_index_get'

class `sqlobject.tests.test_indexes.` `PersonIndexGet2`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `addresses`
  property `age`
  classmethod `byName`(val, connection=None)
  `j` = person_index_get2
  property `name`
  `q` = person_index_get2
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = [<sqlobject.joins.MultipleJoin object>]
    `joins` = [<sqlobject.joins.SOMultipleJoin object>]
    `soClass`

      alias of `sqlobject.tests.test_indexes.PersonIndexGet2`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'person_index_get2'

class `sqlobject.tests.test_indexes.` `SOIndex1`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_index1
  property `name`
  `nameIndex` = <sqlobject.index.SODatabaseIndex object>
  `nameIndex2` = <sqlobject.index.SODatabaseIndex object>
  `nameIndex3` = <sqlobject.index.SODatabaseIndex object>
  property `number`
  `q` = so_index1
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = [<sqlobject.index.SODatabaseIndex object>, <sqlobject.index.SODatabaseIndex object>, <sqlobject.index.SODatabaseIndex object>]
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_indexes.SOIndex1`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_index1'

class `sqlobject.tests.test_indexes.` `SOIndex2`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_index2
  property `name`
  `nameIndex` = <sqlobject.index.SODatabaseIndex object>
  `q` = so_index2
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = [<sqlobject.index.SODatabaseIndex object>]
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_indexes.SOIndex2`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_index2'

`sqlobject.tests.test_indexes.` `test_index_get_1`()

`sqlobject.tests.test_indexes.` `test_index_get_2`()

`sqlobject.tests.test_indexes.` `test_indexes_1`()

`sqlobject.tests.test_indexes.` `test_indexes_2`()